%
%   Phase-amplitude coupling using Modulation Index (MI) over time
%
%   BENESCO Lecture series on signal analysis
%   Mojtaba Bandarabadi
%   Inselspital, Bern, 5 May 2017
%   for any question send email to: m.bandarabadi@gmail.com
%

%% Clean up and load signal
clear; close all; clc

load('data_CFC.mat')

%% Modulation index over time
winLen = 5;  % length of moving window for segmentation in second
stepLen = 1; % step of moving window in second

phaseFreq = [6 9]; % frequency band for phase
ampFreq = [55 95]; % frequency band for amplitude
[MI, meanAmp] = f_modulationIndex(signal, sampRate, winLen, stepLen, phaseFreq, ampFreq);

%% Plot results
figure('Position',[30,60,600,400],'Color',[1 1 1]);
time = 1:length(MI);

subplot(4,1,1);
plot(time,MI);
box off
axis tight
ylabel('MI');
set(gca,'fontsize',12);

subplot(4,1,[2:4]);
imagesc(time, 10:20:360, meanAmp')
set(gca,'YDir','normal');
box off
ylabel('phase (degree)');
xlabel('time');
set(gca,'fontsize',12);
